@@ -48,7 +48,7 @@ KDefaultPropertyFactory::KDefaultPropertyFactory()
  : KPropertyWidgetsFactory()
 {
     KPropertyUtilsPrivate::setupPrivateIconsResourceWithMessage(
-        QLatin1String(KPROPERTYWIDGETS_BASE_NAME_LOWER),
+        QString::fromLatin1("kproperty%1").arg(KPROPERTY_STABLE_VERSION_MAJOR),
         QString::fromLatin1("icons/kproperty_%1.rcc").arg(KPropertyUtilsPrivate::supportedIconTheme()), QtFatalMsg);
 
     addEditor( KProperty::Bool, new KPropertyBoolDelegate );
@@ -75,6 +75,7 @@ KDefaultPropertyFactory::KDefaultPropertyFactory()
     addEditor( KProperty::UInt, new KPropertyIntSpinBoxDelegate ); //!< @todo add more specialized delegate
     addEditor( KProperty::ULongLong, new KPropertyIntSpinBoxDelegate ); //!< @todo add more specialized delegate
     addEditor( KProperty::Url, new KPropertyUrlDelegate );
+    addEditor( KProperty::ComposedUrl, new KPropertyUrlDelegate );
     addEditor( KProperty::ValueFromList, new KPropertyComboBoxDelegate );
 }
 
