@@ -23,17 +23,26 @@
 #include "KPropertyLineStyleItemDelegate_p.h"
 #include "KPropertyUtils_p.h"
 
+#include <QApplication>
 #include <QPen>
 
+class Q_DECL_HIDDEN KPropertyLineStyleComboEditor::Private
+{
+public:
+    Private()
+    {
+    }
+};
+
 KPropertyLineStyleComboEditor::KPropertyLineStyleComboEditor(QWidget *parent)
-    : KPropertyLineStyleSelector(parent)
+    : KPropertyLineStyleSelector(parent), d(new Private)
 {
     connect(this, SIGNAL(activated(int)), this, SLOT(slotValueChanged(int)));
 
     int paddingTop = 1;
     int paddingLeft = 0;
     const QString style(parent->style()->objectName());
-    if (!KPropertyUtils::gridLineColor(this).isValid()) {
+    if (!KPropertyUtilsPrivate::gridLineColor(this).isValid()) {
         setFrame(false);
         paddingTop = 0;
     }
@@ -51,6 +60,7 @@ KPropertyLineStyleComboEditor::KPropertyLineStyleComboEditor(QWidget *parent)
 
 KPropertyLineStyleComboEditor::~KPropertyLineStyleComboEditor()
 {
+    delete d;
 }
 
 QVariant KPropertyLineStyleComboEditor::value() const
@@ -80,7 +90,7 @@ void KPropertyLineStyleComboEditor::slotValueChanged(int)
 
 KPropertyLineStyleComboDelegate::KPropertyLineStyleComboDelegate()
 {
-    options.removeBorders = false;
+    options()->setBordersVisible(true);
 }
 
 QWidget * KPropertyLineStyleComboDelegate::createEditor( int type, QWidget *parent,
@@ -95,7 +105,7 @@ QWidget * KPropertyLineStyleComboDelegate::createEditor( int type, QWidget *pare
 void KPropertyLineStyleComboDelegate::paint( QPainter * painter,
     const QStyleOptionViewItem & option, const QModelIndex & index ) const
 {
-    const KPropertyUtils::PainterSaver saver(painter);
+    const KPropertyUtilsPrivate::PainterSaver saver(painter);
     Qt::PenStyle penStyle = Qt::NoPen;
     if (hasVisibleStyle(index.data(Qt::EditRole))) {
         penStyle = static_cast<Qt::PenStyle>(index.data(Qt::EditRole).toInt());
